import logging

def get_logger(name):
    """
    Creates logger object using name. The returned logger object logs to the standard error stream and formats
    the messages.

    Parameters
    ----------
        name: The name that gets passed to the logger.getLogger function.
    Returns
    -------
        A logger instance with the given name.
    """

    logger = logging.getLogger(name)
    logger.setLevel(logging.INFO)
    stderr_handler = logging.StreamHandler()
    formatter = logging.Formatter("%(asctime)s | %(levelname)s | %(name)s | %(message)s", datefmt="%Y-%m-%d %H:%M:%S")
    stderr_handler.setFormatter(formatter)
    logger.addHandler(stderr_handler)
    return logger


import requests


def call(task_type, url, mode):
    valid = {'_sync', '_async'}
    if mode not in valid:
        raise ValueError("call: status must be one of %r." % valid)

    r = requests.get(url + task_type + mode)
    queue_name = r.json()['queue_name']
    return queue_name


import pika
import requests
from io_orbit.logger.laccuna_logging import get_logger

laccuna_logger = get_logger(__name__)


class ExchangeReceiver(object):
    def __init__(
        self,
        username,
        password,
        host,
        port,
        exchange,
        exchange_type,
        service,
        service_name,
        logger,
    ):
        self.service_worker = service
        self.service_name = service_name
        self.exchange = exchange
        self.logger = logger

        credentials = pika.PlainCredentials(username, password)
        connection = pika.BlockingConnection(
            pika.ConnectionParameters(host=host, port=port, credentials=credentials)
        )

        channel = connection.channel()
        channel.exchange_declare(exchange=self.exchange, exchange_type=exchange_type)

        result = channel.queue_declare(queue="", exclusive=True)
        queue_name = result.method.queue

        channel.queue_bind(exchange=self.exchange, queue=queue_name)
        channel.basic_consume(
            queue=queue_name, on_message_callback=self.on_request, auto_ack=True
        )

        laccuna_logger.info("Awaiting requests from [x] " + self.exchange + " [x]")
        channel.start_consuming()

    def on_request(self, ch, method, props, body):
        service_instance = self.service_worker()

        if self.logger is not None:
            params = {
                "correlation_id": "-",
                "queue_name": self.exchange,
                "service_name": self.service_name,
                "task_type": "start",
            }
            try:
                requests.post(self.logger, json=params)
            except requests.exceptions.RequestException as e:
                laccuna_logger.info(
                    "Logger service is not available. Exception is: {e}"
                )

        response, task_type = service_instance.call(body)

        if self.logger is not None:
            params = {
                "correlation_id": "-",
                "queue_name": self.exchange,
                "service_name": self.service_name,
                "task_type": "end",
            }
            try:
                requests.post(self.logger, json=params)
            except requests.exceptions.RequestException as e:
                laccuna_logger.info(
                    "Logger service is not available. Exception is: {e}"
                )

        laccuna_logger.info("Processed request:", task_type)



import pika
import uuid
import requests
from io_orbit.logger.laccuna_logging import get_logger

laccuna_logger = get_logger(__name__)


class ExchangeProducer(object):
    def __init__(self, username, password, host, port, service_name, logger):
        self.username = username
        self.password = password
        self.host = host
        self.port = port
        self.service_name = service_name
        self.logger = logger

    def call(self, exchange, exchange_type, payload):
        credentials = pika.PlainCredentials(self.username, self.password)
        connection = pika.BlockingConnection(
            pika.ConnectionParameters(
                host=self.host, port=self.port, credentials=credentials
            )
        )
        channel = connection.channel()
        channel.exchange_declare(exchange=exchange, exchange_type=exchange_type)

        corr_id = str(uuid.uuid4())

        if self.logger is not None:
            params = {
                "correlation_id": corr_id,
                "queue_name": exchange,
                "service_name": self.service_name,
                "task_type": "start",
            }
            try:
                requests.post(self.logger, json=params)
            except requests.exceptions.RequestException as e:
                laccuna_logger.info(
                    "Logger service is not available. Exception is: {e}"
                )

        channel.basic_publish(exchange=exchange, routing_key="", body=payload)
        connection.close()

        if self.logger is not None:
            params = {
                "correlation_id": corr_id,
                "queue_name": exchange,
                "service_name": self.service_name,
                "task_type": "end",
            }
            try:
                requests.post(self.logger, json=params)
            except requests.exceptions.RequestException as e:
                laccuna_logger.info(
                    "Logger service is not available. Exception is: {e}"
                )



import os
import json
from google.cloud import storage
from google.oauth2 import service_account

from io_orbit.logger.laccuna_logging import get_logger

logger = get_logger(__name__)


class GoogleCloudStorageRights:
    def __init__(self) -> None:
        try:
            self.credentials = service_account.Credentials.from_service_account_info(
                eval(os.getenv("GOOGLE_CREDENTIALS"))
            )
        except Exception as e:
            logger.exception(f"Error while initializing google credentials: {e}")
        self.initialize_app = storage.Client(credentials=self.credentials)
        pass

    def initialize_gcs_client(self):
        return storage.Client(credentials=self.credentials)


try:
    logger.info(f"Instantiating GCS Client...")
    google_client = GoogleCloudStorageRights().initialize_gcs_client()
    logger.info(f"GCS Client instantiated.")
except Exception as e:
    logger.error(f"Error instantiating GCS Client: {e}")



import pika
import uuid
import requests
import json
from io_orbit.logger.laccuna_logging import get_logger

laccuna_logger = get_logger(__name__)


class EventProducer(object):
    def __init__(self, username, password, host, port, service_name, logger):
        self.service_name = service_name
        self.logger = logger
        self.credentials = pika.PlainCredentials(username, password)
        self.connection = pika.BlockingConnection(
            pika.ConnectionParameters(
                host=host, port=port, credentials=self.credentials
            )
        )
        self.channel = self.connection.channel()

        result = self.channel.queue_declare(queue="", exclusive=True)
        self.callback_queue = result.method.queue

        self.channel.basic_consume(
            queue=self.callback_queue,
            on_message_callback=self.on_response,
            auto_ack=True,
        )

    def on_response(self, ch, method, props, body):
        if self.corr_id == props.correlation_id:
            self.response = body

    def call(self, queue_name, payload):
        self.response = None
        self.corr_id = str(uuid.uuid4())

        try:
            queue_state = self.channel.queue_declare(
                queue_name, passive=True, durable=True
            )
            # laccuna_logger.info(f"Queue state is: {queue_state}")
            if queue_state.method.consumer_count == 0:
                self.logger_helper(
                    self.corr_id,
                    queue_name,
                    self.service_name,
                    self.logger,
                    "start",
                    "No subscriber available",
                )

                response = {
                    "error": "No subscriber available",
                    "Queue State": queue_state,
                }
                result = json.dumps(response)

                return result
        except Exception as e:
            laccuna_logger.info(f"Event Producer Exception is: {e}")
            self.logger_helper(
                self.corr_id,
                queue_name,
                self.service_name,
                self.logger,
                "start",
                "No subscriber available",
            )

            response = {"error": "No subscriber available"}
            result = json.dumps(response)

            return result

        self.logger_helper(
            self.corr_id, queue_name, self.service_name, self.logger, "start", "-"
        )

        self.channel.basic_publish(
            exchange="",
            routing_key=queue_name,
            properties=pika.BasicProperties(
                reply_to=self.callback_queue, correlation_id=self.corr_id
            ),
            body=payload,
        )

        while self.response is None:
            self.connection.process_data_events()

        self.logger_helper(
            self.corr_id, queue_name, self.service_name, self.logger, "end", "-"
        )

        return self.response

    def logger_helper(
        self, corr_id, queue_name, service_name, logger, task_type, description
    ):
        if self.logger is not None:
            params = {
                "correlation_id": corr_id,
                "queue_name": queue_name,
                "service_name": service_name,
                "task_type": task_type,
                "description": description,
            }
            try:
                requests.post(logger, json=params)
            except requests.exceptions.RequestException as e:
                laccuna_logger.info(
                    "Logger service is not available. Exception is: {e}"
                )



import os
import json
import firebase_admin
from firebase_admin import credentials
from firebase_admin import firestore

from io_orbit.logger.laccuna_logging import get_logger

logger = get_logger(__name__)


class FirebaseRights:
    def __init__(self) -> None:
        try:
            self.credentials = credentials.Certificate(
                eval(os.getenv("FIREBASE_CREDENTIALS"))
            )
        except Exception as e:
            logger.exception(f"Error while initializing firebase credentials: {e}")
        self.initialize_app = firebase_admin.initialize_app(self.credentials)
        pass

    def initialize_firebase_client(self):
        return firestore.client()


if not firebase_admin._apps:
    logger.info(f"Instantiating Firebase App...")
    firestore_client = FirebaseRights().initialize_firebase_client()
    logger.info(f"Firebase app instantiated.")
else:
    logger.warning(
        f"Firebase app already instantiated as: {firebase_admin.get_app().name} under project: {firebase_admin._apps[firebase_admin.get_app().name].project_id}"
    )



import pika
import requests
import json
from io_orbit.logger.laccuna_logging import get_logger

laccuna_logger = get_logger(__name__)


class EventReceiver(object):
    def __init__(
        self, username, password, host, port, queue_name, service, service_name, logger
    ):
        self.service_worker = service
        self.service_name = service_name
        self.queue_name = queue_name
        self.logger = logger

        credentials = pika.PlainCredentials(username, password)
        connection = pika.BlockingConnection(
            pika.ConnectionParameters(host=host, port=port, credentials=credentials)
        )

        channel = connection.channel()
        channel.queue_declare(queue=queue_name)

        channel.basic_qos(prefetch_count=1)
        channel.basic_consume(queue=queue_name, on_message_callback=self.on_request)

        laccuna_logger.info("Awaiting requests from [x] " + queue_name + " [x]")
        channel.start_consuming()

    def on_request(self, ch, method, props, body):
        service_instance = self.service_worker()

        self.logger_helper(
            props.correlation_id,
            self.queue_name,
            self.service_name,
            self.logger,
            "start",
            "-",
        )

        try:
            response, task_type = service_instance.call(body)

            ch.basic_publish(
                exchange="",
                routing_key=props.reply_to,
                properties=pika.BasicProperties(correlation_id=props.correlation_id),
                body=response,
            )
            ch.basic_ack(delivery_tag=method.delivery_tag)

            self.logger_helper(
                props.correlation_id,
                self.queue_name,
                self.service_name,
                self.logger,
                "end",
                "-",
            )

            print("Processed request:", task_type)
        except Exception as e:
            laccuna_logger.info(f"Event Receiver Exception is: {e}")
            laccuna_logger.exception(e)
            response = {
                "error": "Receiver exception",
                "queue": self.queue_name,
                "service_name": self.service_name,
                "correlation_id": props.correlation_id,
            }
            result = json.dumps(response)

            self.logger_helper(
                props.correlation_id,
                self.queue_name,
                self.service_name,
                self.logger,
                "end",
                "Receiver exception",
            )

            ch.basic_publish(
                exchange="",
                routing_key=props.reply_to,
                properties=pika.BasicProperties(correlation_id=props.correlation_id),
                body=result,
            )
            ch.basic_ack(delivery_tag=method.delivery_tag)

    def logger_helper(
        self, corr_id, queue_name, service_name, logger, task_type, description
    ):
        if self.logger is not None:
            params = {
                "correlation_id": corr_id,
                "queue_name": queue_name,
                "service_name": service_name,
                "task_type": task_type,
                "description": description,
            }
            try:
                requests.post(logger, json=params)
            except requests.exceptions.RequestException as e:
                laccuna_logger.info(
                    "Logger service is not available. Exception is: {e}"
                )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['io_orbit',
 'io_orbit.cloud_configurations',
 'io_orbit.events',
 'io_orbit.logger',
 'io_orbit.workflow']

package_data = \
{'': ['*']}

install_requires = \
['firebase-admin>=5.2.0,<6.0.0',
 'google-cloud-storage>=2.4.0,<3.0.0',
 'pika>=1.2.0,<2.0.0',
 'requests>=2.25.1,<3.0.0']

entry_points = \
{'console_scripts': ['io-orbit = io_orbit:main']}

setup_kwargs = {
    'name': 'io-orbit',
    'version': '0.0.8',
    'description': 'Simple and flexible ML workflow engine',
    'long_description': '<br />\n<p align="center">\n  <a href="https://laccuna.com">\n    <img src="https://storage.googleapis.com/io-public-assets/io-arche-logo.png" alt="Logo" width="846" height="448">\n  </a>\n\n  <h3 align="center">🛰 Welcome to ioOrbit. 🛰</h3>\n\n  <p align="center">\n    Simple and flexible ML workflow engine. This library is meant to wrap all reusable code to simplify workflow implementation.\n    <br />\n    <br />\n  </p>\n</p>\n\n\n## Tools 🧰\n\n- Cloud config handler\n- Flexible logger \n- API to communicate with RabbitMQ\n- Workflow helper\n\n\n## License 🔐\n\nLicensed under the Apache License, Version 2.0.',
    'author': 'laccuna',
    'author_email': 'team@laccuna.io',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



import requests
from io_orbit.logger.laccuna_logging import get_logger

laccuna_logger = get_logger(__name__)


def call(logger, params):
    try:
        requests.post(logger, json=params)
    except requests.exceptions.RequestException as e:
        laccuna_logger.info("Logger service is not available. Exception is: {e}")
